#
# spec file for package pcmciautils
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           pcmciautils
BuildRequires:  bison flex
%if 0%{?suse_version} > 1130
BuildRequires:  sysfsutils-devel
%else
BuildRequires:  sysfsutils
%endif
Url:            http://kernel.org/pub/linux/utils/kernel/pcmcia/pcmcia.html
Version:        017
Release:        113.114.1
Summary:        Utilities for PC-Cards
License:        GPLv2+
Group:          Hardware/Other
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Obsoletes:      pcmcia < 017
Provides:       pcmcia >= 017
PreReq:         permissions
Supplements:    modalias(pci:v*d*sv*sd*bc06sc07i00*)
AutoReqProv:    on
Source:         pcmciautils-%{version}.tar.bz2
Source1:        suse-files.tar.bz2
Source2:        cis-files.tar.bz2
Patch1:         pcmciautils_config.opts.202500.diff
Patch2:         pcmciautils_fix1.diff

%description
This package enables the usage of PC-Cards with Linux. It provides
hotplug scripts, and tools that set up sockets and cards. Since kernel
2.6.13 card injection and removal are handled completely via hotplug.
Therefore, a daemon like 'cardmgr' is no longer needed. Soft ejecting
and inserting cards can be done with pccardctl (it was cardctl before).
There are also some tools for debugging and CIS handling.



Authors:
--------
    Dominik Brodowski <linux@brodo.de>
    David Hinds <dhinds@pcmcia.sourceforge.edu>

%prep
%setup -n pcmciautils-%{version} 
%patch1
%patch2 -p1
%setup -n pcmciautils-%{version} -T -D -a 1
%setup -n pcmciautils-%{version} -T -D -a 2

%build
make all DEF_CFLAGS="$RPM_OPT_FLAGS" STRIPCMD=true
# make debugtools

%install
make install DESTDIR=%{buildroot}
install -m 644 suse-files/NOTE %{buildroot}/etc/pcmcia
mkdir -p %{buildroot}/lib/firmware
install -m 644 cis-files/* %{buildroot}/lib/firmware
mkdir -p %{buildroot}/%{_docdir}/pcmciautils
install -m 644 suse-files/README.SUSE %{buildroot}/%{_docdir}/pcmciautils

%post
%run_permissions
rm -vf /etc/sysconfig/pcmcia
%verifyscript
%verify_permissions -e /sbin/pccardctl

%files
%defattr(-,root,root)
%dir /etc/pcmcia
%config /etc/pcmcia/config.opts
/etc/pcmcia/NOTE
/lib/udev/rules.d/60-pcmcia.rules
%verify(not mode) %attr(4750,root,trusted) /sbin/pccardctl
%dir /lib/udev
%dir /lib/udev/rules.d
/lib/udev/pcmcia-check-broken-cis
/lib/udev/pcmcia-socket-startup
/sbin/lspcmcia
/lib/firmware/*
/%{_docdir}/pcmciautils
#/%{_mandir}/man[458]/*
/%{_mandir}/man8/*

%changelog
* Sat Sep  3 2011 vbotka@suse.de
- null termination of the pccardctl_opts added (bnc#567197)
* Thu Nov 11 2010 coolo@novell.com
- fix file list
* Tue Sep  7 2010 aj@suse.de
- BuildRequire sysfsutils-devel
* Tue Jul 20 2010 vbotka@suse.de
- updated to version 017:
  changes against pcmciautils-016
  - Always use path without trailing slash
  - Use architecture-specific config.opts if it exists
  - Add config.opts for hppa
  - Add config.opts for powerpc
  - pcmciautils: improve for cross-builds
  changes against pcmciautils-015
  - Install udev helpers in customizable directory
  - pccardctl: add array out-of-bounds exception
  - fix parallel build of ccdv
- fixed bnc#623638
* Fri Sep 26 2008 seife@suse.de
- add missing directory /lib/udev to filelist to fix build
* Thu Aug 28 2008 vbotka@suse.cz
- updated to version 015:
  - fix for udev-094 or newer
  - improved udev rules
  - status "command" now implemented in pccardctl
  - documentation fixes
- moved udev helpers to /lib/udev/
* Fri Jul 27 2007 zoz@suse.de
- removed usage of hwup/down and sysconfig/pcmcia
  we now use the upstream udev rules for device initialisation
- added upstream patch for udev094 (no more MODALIAS key name)
* Thu Mar 29 2007 rguenther@suse.de
- add bison and flex BuildRequires
* Mon Mar 19 2007 ro@suse.de
- removed directory /lib/firmware from filelist (in filesystem)
* Mon Jan  8 2007 zoz@suse.de
- update to version 014:
  + fix fallthrough from 'pccardctl ls' to 'pccardctl insert'
  + symlink man page too
  + lspcmcia: fix iomem/ioports mixup
  + handle big endian host in dump_cis
  from version 013:
  + check-broken-cis: endless loop
  + updated runtime powermanagement handling
  + add "lspcmcia"
  + pccardctl: return error values from low-level functions
  + pccardctl: don't break lspcmcia if /sys/class/*/*/device is removed
- added comment in config.opts (bug 202500)
* Wed May 24 2006 schwab@suse.de
- Don't strip binaries.
* Thu Mar 30 2006 zoz@suse.de
- added supplement modalias in specfile (Bug 161340)
* Fri Jan 27 2006 zoz@suse.de
- update to version 012:
  + Makefile: fix double prefix
  + Add output for "pccardctl status"
  + pccardctl: do not use deprecated sysfs_read_attribute_value()
  + Add improvements to config.opts from ubuntu/debian
  + Makefile: allow for statically linked binaries
  + Add improvements to config.opts from opensuse
- added some patches from git:
  + avoid endless loop in pcmcia-check-broken-cis
  + fixed some typos in documentation
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Dec 15 2005 zoz@suse.de
- update to version 011 (we still use our own udev rules)
- removed hotplug/*rc files
* Mon Sep  5 2005 zoz@suse.de
- removed obsolete /etc/hotplug/*agent
- changed io ranges in config.opts due to experience with pcmcia_cs
  and current bugs (97859, 105218)
- pcmcia and pcmcia_socket events wont be handled if /dev/shm/nopcmcia
  exists (will be written with boot option 'pcmcia=off')
- Finally wrote README.SUSE
* Fri Aug 26 2005 kukuk@suse.de
- Provide pcmcia package to enable package at update
- Remove duplicate PreReq
* Mon Aug 22 2005 zozl@suse.de
- added cis files to package, install them to /lib/firmware
- added hwup function files
- changed /etc/hotplug/*rc: they call now hwup directly
- replaced *agent with hwup
- added /etc/sysconfig/pcmcia
* Mon Aug 15 2005 kkeil@suse.de
- add label to support ISDN PCMCIA hotplug via udev (#102342)
* Fri Aug  5 2005 ro@suse.de
- fix permissions handling
- build as non-root
* Mon Aug  1 2005 zoz@suse.de
- added /etc/udev to filelist
* Mon Aug  1 2005 zoz@suse.de
- added /etc/udev/rules.d/50-pcmcia.rules
* Sat Jul 30 2005 zoz@suse.de
- initial package, version 007 (with the license to kill cardmgr ;)
- hotplug *.rc scripts: call *.agent directly; we don't have /sbin/hotplug
- pcmcia_socket.agent: also load module pcmcia
